# Skanym Core
This repository contains The core fonctionalities to create, edit and export 3D animations using the skeletal animation principle.

## Wikis
(Motion Machine)[Link to the wiki]
(Skanym)[Link to the wiki]

## Historical context
The skeletal-animation package was originally developed as part of a bachelor thesis in 2021-2022 ([link]() to the original repository [access required]). It was then maintained/extended for future use ([link]() to the latest version [access required]).
This repository contains a fork of the core modules of the skeletal-animation package. The goal is to improve upon those modules
to better fit the requirements for the Motion Machine project.




